==> biostime-openapi-sdk-1.2.1.RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/hcm/HcmGetUserListReqBean.java <==
package global.hh.openapi.sdk.api.bean.hcm;


/**
 * @description: 用户详细信息
 * @author: 777771
 * @date: 2023-27-27 14:27:39
 */
public class HcmGetUserListReqBean {
    /**
     * 人员编码
     */
    private String code;

    /**
     * 人员名称
     */
    private String name;

    /**
     * 是否增量
     */
    private Boolean incrementalFlag;

    /**
     * 开始时间
     */
    private String startDate;

    /**
     * 结束时间
     */
    private String endDate;

    /**
     * 手机号码
     */
    private String mobile;

    /**
     * 0:无效,1有效
     */
    private String status;

    /**
     * 部门名称
     */
    private String deptName;

    /**
     * 部门编号
     */
    private String deptCode;

    /**
     * 是否分页
     */
    private String paginationFlag;

    /**
     * 当前页
     */
    private String page;

    /**
     * 每页条数
     */
    private String pageSize;

    public HcmGetUserListReqBean(){
    }

    public HcmGetUserListReqBean(String code,String name,Boolean incrementalFlag,String startDate,String endDate,String mobile,String status,String deptName,String deptCode,String paginationFlag,String page,String pageSize){
        this.code=code;
        this.name=name;
        this.incrementalFlag=incrementalFlag;
        this.startDate=startDate;
        this.endDate=endDate;
        this.mobile=mobile;
        this.status=status;
        this.deptName=deptName;
        this.deptCode=deptCode;
        this.paginationFlag=paginationFlag;
        this.page=page;
        this.pageSize=pageSize;
    }

    private String getCode() {
        return code;
    }

    private void setCode(String code) {
        this.code = code;
    }
    private String getName() {
        return name;
    }

    private void setName(String name) {
        this.name = name;
    }
    private Boolean getIncrementalFlag() {
        return incrementalFlag;
    }

    private void setIncrementalFlag(Boolean incrementalFlag) {
        this.incrementalFlag = incrementalFlag;
    }
    private String getStartDate() {
        return startDate;
    }

    private void setStartDate(String startDate) {
        this.startDate = startDate;
    }
    private String getEndDate() {
        return endDate;
    }

    private void setEndDate(String endDate) {
        this.endDate = endDate;
    }
    private String getMobile() {
        return mobile;
    }

    private void setMobile(String mobile) {
        this.mobile = mobile;
    }
    private String getStatus() {
        return status;
    }

    private void setStatus(String status) {
        this.status = status;
    }
    private String getDeptName() {
        return deptName;
    }

    private void setDeptName(String deptName) {
        this.deptName = deptName;
    }
    private String getDeptCode() {
        return deptCode;
    }

    private void setDeptCode(String deptCode) {
        this.deptCode = deptCode;
    }
    private String getPaginationFlag() {
        return paginationFlag;
    }

    private void setPaginationFlag(String paginationFlag) {
        this.paginationFlag = paginationFlag;
    }
    private String getPage() {
        return page;
    }

    private void setPage(String page) {
        this.page = page;
    }
    private String getPageSize() {
        return pageSize;
    }

    private void setPageSize(String pageSize) {
        this.pageSize = pageSize;
    }
}

==> biostime-openapi-sdk-1.5.9.2-RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/hcm/HcmGetUserListReqBean.java <==
package global.hh.openapi.sdk.api.bean.hcm;


/**
 * @description: 用户详细信息
 * @author: 777771
 * @date: 2023-27-27 14:27:39
 */
public class HcmGetUserListReqBean {
    /**
     * 人员编码
     */
    private String code;

    /**
     * 人员名称
     */
    private String name;

    /**
     * 是否增量
     */
    private Boolean incrementalFlag;

    /**
     * 开始时间
     */
    private String startDate;

    /**
     * 结束时间
     */
    private String endDate;

    /**
     * 手机号码
     */
    private String mobile;

    /**
     * 0:无效,1有效
     */
    private String status;

    /**
     * 部门名称
     */
    private String deptName;

    /**
     * 部门编号
     */
    private String deptCode;

    /**
     * 是否分页,不分页传false
     */
    private String paginationFlag;

    /**
     * 当前页
     */
    private String page;

    /**
     * 每页条数
     */
    private String pageSize;

    public HcmGetUserListReqBean(){
    }

    public HcmGetUserListReqBean(String code,String name,Boolean incrementalFlag,String startDate,String endDate,String mobile,String status,String deptName,String deptCode,String paginationFlag,String page,String pageSize){
        this.code=code;
        this.name=name;
        this.incrementalFlag=incrementalFlag;
        this.startDate=startDate;
        this.endDate=endDate;
        this.mobile=mobile;
        this.status=status;
        this.deptName=deptName;
        this.deptCode=deptCode;
        this.paginationFlag=paginationFlag;
        this.page=page;
        this.pageSize=pageSize;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Boolean getIncrementalFlag() {
        return incrementalFlag;
    }

    public void setIncrementalFlag(Boolean incrementalFlag) {
        this.incrementalFlag = incrementalFlag;
    }
    public String getStartDate() {
        return startDate;
    }

    public void setStartDate(String startDate) {
        this.startDate = startDate;
    }
    public String getEndDate() {
        return endDate;
    }

    public void setEndDate(String endDate) {
        this.endDate = endDate;
    }
    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }
    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }
    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
    public String getDeptCode() {
        return deptCode;
    }

    public void setDeptCode(String deptCode) {
        this.deptCode = deptCode;
    }
    public String getPaginationFlag() {
        return paginationFlag;
    }

    public void setPaginationFlag(String paginationFlag) {
        this.paginationFlag = paginationFlag;
    }
    public String getPage() {
        return page;
    }

    public void setPage(String page) {
        this.page = page;
    }
    public String getPageSize() {
        return pageSize;
    }

    public void setPageSize(String pageSize) {
        this.pageSize = pageSize;
    }
}
